%Calculates the mass flux from the surge to the flow
%K. Kelfoun, Apr. 2021 - UCA / LMV - lmv.uca.fr/kelfoun-karim

%Particle settling velocity (Doyle et al)
used = coef_a2*sqrt( ( 4*(rhop-rhog)*g*d_part)./(3*coef_Cd*rhog) );

%Mass flux from the surge en kg/m/s
flux_mass_sg = (rhoS-rhog).*used;
flux_mass_sg(flux_mass_sg<0)=0;


%Removes the surge if lighter than atmosphere
Vlost = Vlost+sum( hw(rhoS<rhoa).*rhoS(rhoS<rhoa)/rhoD.*S(rhoS<rhoa) ) ;
hw(rhoS<rhoa)=0;
Rw(rhoS<rhoa)=0;
rhoS(rhoS<rhoa)=rhoa;

%variation of rho * hw of the surge
dRw = min(Rw, flux_mass_sg*dt) ;
Rw = Rw - dRw ;  %Rw = kg/m

%Thickness added to the flow or the deposit
h = h + dRw./rhoD;
hsed = hsed + dRw./rhoD;   %= records all that falls at a given location
h2nd = h2nd + dRw./rhoD;   %= records all that falls at a given location to detect surge-derived pyroclastic flow

%hw does not change during sedimentation (only the density)
%the momentum conservation is computed automatically by VolcFlow
